
import WordPanel;

import java.applet.Applet;
import java.awt.BorderLayout;
import java.awt.Panel;
import java.awt.Button;
import java.awt.Checkbox;
import java.awt.Color;
import java.awt.Event;
import java.util.Vector;
import java.util.StringTokenizer;

public class MagneticWords extends Applet implements Runnable
	{
	/*
	Implement a panel of moveable words imitating magnetized words stuck
	on a refrigerator.
	*/

	//the panel of words
	private WordPanel wordsPanel;

	//the user interface controls
	private Button scrambleWordsButton;
	private Checkbox pushableWordsCheckbox;

	//the number of times to rescramble the words
	private final static int NUM_SCRAMBLE_ITERATIONS = 5;

	//the number of milliseconds to sleep between scrambles
	private final static int SCRAMBLE_SLEEPTIME = 100;

	/////////////////////////////////////////////////////////////////////
	public void init()
		{
		/*
		Setup the words in a central panel and put the control pad on the
		bottom panel.
		*/

		//fetch the words
		String wordList = this.getParameter("words");
		if (wordList == null)
			wordList = "missing input";
		Vector words = new Vector();
		StringTokenizer tokenizer = new StringTokenizer(wordList);
		while (tokenizer.hasMoreTokens())
			words.addElement(tokenizer.nextToken());

		//layout the user interface components
		this.setLayout(new BorderLayout());

		//setup the words panel
		wordsPanel = new WordPanel(words);
		this.add("Center", wordsPanel);

		//setup the control pad
		scrambleWordsButton = new Button("Scramble Words");
		pushableWordsCheckbox = new Checkbox("Make Words Pushable");
		Panel controlPad = new Panel();
		controlPad.add(scrambleWordsButton);
		controlPad.add(pushableWordsCheckbox);
		this.add("South", controlPad);

		this.setBackground(Color.black);
		}

	/////////////////////////////////////////////////////////////////////
	public boolean action(Event event, Object argument)
		{
		if (event.target.equals(pushableWordsCheckbox))
			{
			wordsPanel.setWordsPushable(((Boolean) argument).booleanValue());

			return true;
			}

		if (event.target.equals(scrambleWordsButton))
			{
			(new Thread(this)).start();

			return true;
			}

		return super.action(event, argument);
		}

	/////////////////////////////////////////////////////////////////////
	public void run()
		{
		/*
		Scramble the words a few times, painting them after each scramble.

		Note: wordsPanel is a Panel, therefore it knows how to repaint()
		itself into its own graphics context, so there's no need to pass a
		graphics context to it.
		*/

		for (int i = 0; i < NUM_SCRAMBLE_ITERATIONS; i++)
			{
			wordsPanel.scramble();
			wordsPanel.repaint();
			try { Thread.sleep(SCRAMBLE_SLEEPTIME); }
			catch (InterruptedException ignored) {}
			}
		}
	}
